@@ -1,15 +1,12 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2026, by Samuel Williams.
+# Copyright, 2019-2025, by Samuel Williams.
 
 source "https://rubygems.org"
 
-# Specify your gem's dependencies in protocol-http.gemspec
 gemspec
 
-# gem "async-http", path: "../async-http"
-
 group :maintenance, optional: true do
 	gem "bake-modernize"
 	gem "bake-gem"
@@ -17,21 +14,21 @@ group :maintenance, optional: true do
 	
 	gem "agent-context"
 	
-	gem "utopia-project", "~> 0.18"
+	gem "utopia-project"
 end
 
 group :test do
-	gem "covered"
 	gem "sus"
+	gem "covered"
 	gem "decode"
 	
 	gem "rubocop"
 	gem "rubocop-md"
 	gem "rubocop-socketry"
 	
-	gem "sus-fixtures-async"
-	gem "sus-fixtures-benchmark"
-	
 	gem "bake-test"
 	gem "bake-test-external"
+	
+	gem "stringio"
+	gem "traces"
 end
